whiptail
==================================================

Use whiptail to display dialog boxes from shell scripts.

Installation
------------

  $ pip install whiptail

Links
-----

* `Fork me on GitHub <https://github.com/marwano/whiptail>`_

